@@ -309,6 +309,9 @@ sub get_arg_spec {
         'P'                 => sub { $opt->{p} = 0 },
         'Q|literal'         => \$opt->{Q},
         'r|R|recurse'       => sub { $opt->{n} = 0 },
+        'range-start=s'     => \$opt->{range_start},
+        'range-end=s'       => \$opt->{range_end},
+        'range-invert!'     => \$opt->{range_invert},
         's'                 => \$opt->{s},
         'show-types'        => \$opt->{show_types},
         'S|smart-case!'     => sub { my (undef,$value) = @_; $opt->{S} = $value; $opt->{i} = 0 if $value; },
